plot_res: Plotting the residuals

Description Usage Arguments Examples

View source: R/plots.R

Description

Plotting the residuals

Usage

1
plot_res(model, na.rm = FALSE, margin = 0.04)

Arguments

model

A trainML object

na.rm

A boolean, if TRUE will ignore missing values, by default set to FALSE

margin

A numeric, define the margin space between the subplot components

Examples

1
2
3
4
5
# Train a time series forecasting model
md <- trainML(input = AirPassengers, trend = list(linear = TRUE), seasonal = "month")

# create a residuals plot
plot_res(md)

RamiKrispin/forecastML documentation built on Nov. 15, 2019, 9:58 a.m.