tsACF: Autocorrelation Function

Description Usage Arguments

View source: R/util function.R

Description

The tsACF function calculate the estimated autocorrelation between a series and its past lags

Usage

1
2
tsACF(input, var = NULL, max.lag = NULL, ci = 0.95, na.rm = FALSE,
  width = 0.01, plot = TRUE)

Arguments

input

A tsibble object

var

A character, optional, defines the variables names to calculate the ACF when having a multuple time series object

max.lag

An integer, defines the maximum number of lags to be used

ci

A numeric between 0 and 1, defines the coverage probablility for confidence interval (by default set to 0.95)

na.rm

A boolean, if set to TRUE will ignore missing values

width

A numeric, defines the plot's autocorrelation lines width

plot

A boolean, if set to TRUE will plot the acf results


RamiKrispin/forecastML documentation built on Nov. 15, 2019, 9:58 a.m.