Description Usage Arguments Examples
Plotting the residuals
1 |
model |
A trainML object |
na.rm |
A boolean, if TRUE will ignore missing values, by default set to FALSE |
margin |
A numeric, define the margin space between the subplot components |
1 2 3 4 5 | # Train a time series forecasting model
md <- trainML(input = AirPassengers, trend = list(linear = TRUE), seasonal = "month")
# create a residuals plot
plot_res(md)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.